# McAfee ePolicy Orchestrator (ePO) DXL Python Client Library

This distribution contains following directories:

- doc
  - Documentation for the ePO DXL Python client library
- lib
  - ePO DXL Python client libraries (.zip, .egg, .whl)
- sample
  - Samples that demonstrate use of the ePO DXL Python client library

Click here to view the documentation which includes installation instructions, ePO DXL Python client library details, and samples.